@@ -1,4 +1,4 @@
-__version__ = '0.2.0'
+__version__ = '0.2.1'
 
 import os
 import shutil
@@ -11,6 +11,8 @@ nox.options.envdir = '../.nox'
 
 @nox.session(python=["3.8"], reuse_venv=False, venv_params=['--system-site-packages'])
 def tests(session):
+    dist_file = f"/tmp/pandas-ml-quant-{__version__}.zip"
+
     # install testing requirements and local dependencies
     session.install("-r", "dev-requirements.txt")
     session.install("-r", "requirements.txt")
@@ -20,7 +22,7 @@ def tests(session):
 
     # create distribution and install
     session.run("python", "setup.py", "sdist",  "-d", "/tmp/", "--formats=zip", env={})
-    session.install(f"/tmp/pandas-ml-quant-{__version__}.zip", "--no-deps")
+    session.install(dist_file, "--no-deps")
 
     # create notebook kernels
     kernel = "ml_quant"
@@ -41,3 +43,6 @@ def tests(session):
 
     # clean up egg info
     shutil.rmtree("pandas_ml_quant.egg-info")
+
+    # make link check
+    session.run("python", "pandas_ml_quant_test/check_links.py", dist_file)
