@@ -1,3 +1,3 @@
-from .backtest_summary import BacktestSummary
 from .binary_weighted_classification_summary import BinaryWeightedClassificationSummary, MultipleBinaryWeightedClassificationSummary
-from .weighted_classification_summary import WeightedClassificationSummary
\ No newline at end of file
+from .weighted_classification_summary import WeightedClassificationSummary
+from .price_prediction_summary import PricePredictionSummary
\ No newline at end of file
