@@ -1,39 +1,16 @@
 from unittest import TestCase
 
-from pandas_ml_quant import PostProcessedFeaturesAndLabels, Constant
 from pandas_ml_quant_test.config import DF_TEST
+from pandas_ml_utils import PostProcessedFeaturesAndLabels, Constant, np
+from pandas_ml_utils.ml.data.extraction.features_and_labels_extractor import FeaturesWithLabels
 
 
 class TestFeaturePostProcesor(TestCase):
 
-    def test_repr(self):
-        fnl = PostProcessedFeaturesAndLabels(
-            features=[
-                "Close",
-                lambda df: df["Close"].ta.trix(),
-            ],
-            feature_post_processor=[
-                lambda df: df.ta.rnn(5)
-            ],
-            labels=[
-                Constant(0)
-            ],
-            targets=[
-                lambda df: df["Close"]
-            ],
-        )
-
-        print(repr(repr(fnl).replace('"', '\"')))
-
-        self.assertEqual(
-            'PostProcessedFeaturesAndLabels(\t[\'Close\', \'                lambda df: df["Close"].ta.trix(),\\n\'], \t[\'                lambda df: df.ta.rnn(5)\\n\'], \t[\'Constant(0)\'], \tNone, \tNone, \tNone, \tNone, \tNone, \t[\'                lambda df: df["Close"]\\n\'], \tNone, \tNone, \t{})',
-            repr(fnl)
-        )
-
     def test_feature_post_processing(self):
         df = DF_TEST.copy()
 
-        (f, min), l, t, w, gl = df._.extract(
+        fl: FeaturesWithLabels = df._.extract(
             PostProcessedFeaturesAndLabels(
                 features=[
                     "Close",
@@ -51,14 +28,14 @@ class TestFeaturePostProcesor(TestCase):
             )
         )
 
-        self.assertEqual((6674, 10), f.shape)
-        self.assertEqual((6674, 1), l.shape)
-        self.assertEqual((6674, 5, 2), f._.values.shape)
+        self.assertEqual((6674, 10), fl.features_with_required_samples.features.shape)
+        self.assertEqual((6674, 1), fl.labels.shape)
+        self.assertEqual((6674, 5, 2), fl.features_with_required_samples.features._.values.shape)
 
     def test_feature_and_label_post_processing(self):
         df = DF_TEST.copy()
 
-        (f, min), l, t, w, gl = df._.extract(
+        fl: FeaturesWithLabels = df._.extract(
             PostProcessedFeaturesAndLabels(
                 features=[
                     "Close",
@@ -80,10 +57,35 @@ class TestFeaturePostProcesor(TestCase):
             )
         )
 
-        self.assertEqual((6672, 30), f.shape)
-        self.assertEqual((6672, 4), l.shape)
-        # FIXME self.assertEqual((6674, 3, 5, 2), f._.values.shape)
+        self.assertEqual((6672, 30), fl.features_with_required_samples.features.shape)
+        self.assertEqual((6672, 4), fl.labels.shape)
+        # FIXME implement chained lagging: self.assertEqual((6674, 3, 5, 2), fl.features_with_required_samples.features._.values.shape)
 
-    def test_post_z_standardisation(self):
-        # FIXME implement me ...
-        pass
\ No newline at end of file
+    def test_post_row_standardisation(self):
+        df = DF_TEST.copy()
+
+        fl: FeaturesWithLabels = df._.extract(
+            PostProcessedFeaturesAndLabels(
+                features=[
+                    lambda df: df["Close"].ta.log_returns(),
+                    lambda df: df["Close"].ta.trix(),
+                    lambda df: df["Close"].ta.rsi(),
+                ],
+                feature_post_processor=[
+                    lambda df: df.ta.rnn(20),
+                    lambda df: df.ta.normalize_row('minmax01', level=1)
+                ],
+                labels=[Constant(0)],
+            )
+        )
+
+        f = fl.features_with_required_samples.features
+
+        self.assertAlmostEqual(1, f.max(axis=1).values.max())
+        self.assertAlmostEqual(0, f.min(axis=1).values.max())
+        self.assertEqual(
+            {0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28,
+             29, 30, 31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 50, 51, 52, 53, 54, 55,
+             56, 57, 58, 59},
+            set(f.apply(np.argmax, axis=1).values)
+        )
\ No newline at end of file
